summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/property.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-15 15:32:11 -0600
committerTimothy Pearson <[email protected]>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /lib/koproperty/property.h
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'lib/koproperty/property.h')
-rw-r--r--lib/koproperty/property.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/koproperty/property.h b/lib/koproperty/property.h
index bc8a503e..9f097c61 100644
--- a/lib/koproperty/property.h
+++ b/lib/koproperty/property.h
@@ -104,7 +104,7 @@ enum PropertyType {
//predefined custom types
ValueFromList = 2000 /**<string value from a list*/,
- Symbol = 2001 /**<tqunicode symbol code*/,
+ Symbol = 2001 /**<unicode symbol code*/,
FontName /**<font name, e.g. "times new roman"*/,
FileURL /**<url of a file*/,
PictureFileURL /**<url of a pixmap*/,
@@ -306,9 +306,9 @@ class KOPROPERTY_EXPORT Property
/*! \return property icon's string. Can be empty. */
TQString icon() const;
- /*! \return a list of all tqchildren for this property, or NULL of there
- is no tqchildren for this property */
- const TQValueList<Property*>* tqchildren() const;
+ /*! \return a list of all children for this property, or NULL of there
+ is no children for this property */
+ const TQValueList<Property*>* children() const;
/*! \return a child property for \a name, or NULL if there is no property with that name. */
Property* child(const TQCString &name);
@@ -407,7 +407,7 @@ class KOPROPERTY_EXPORT Property
protected:
/*! Adds \a prop as a child of this property.
- The tqchildren will be owned by this property. */
+ The children will be owned by this property. */
void addChild(Property *prop);
/*! Adds \a set to this property. */